# SpecularLang
![Python package](https://github.com/Bluepuff71/SpecularLang/workflows/Python%20package/badge.svg)
[![PyPI version](https://img.shields.io/pypi/v/SpecularLang)](https://pypi.org/project/SpecularLang/)

A language for a project I'm working on

Documentation coming soon!
